Font Awesome, the iconic font designed for Bootstrap
Author: Dave Gandy

# Font Awesome

The iconic font designed for Bootstrap

Download
GitHub Project · Version 3.2.1 · Created & Maintained by Dave Gandy

- Follow @fontawesome
- Tweet

Heads up! These docs are for v3.2.1, which is no longer officially supported. Check out the latest version of Font Awesome!

Font Awesome gives you scalable vector icons that can instantly be customized — size, color, drop shadow, and anything that can be done with the power of CSS.

#### One Font, 361 Icons

In a single collection, Font Awesome is a pictographic language of web-related actions.

#### CSS Control

Easily style icon color, size, shadow, and anything that's possible with CSS.

#### Infinite Scalability

Scalable vector graphics means every icon looks awesome at any size.

#### Free, as in Speech

Font Awesome is completely free for commercial use. Check out the license.

#### IE7 Support

Font Awesome supports IE7. If you need it, you have my condolences.

#### Perfect on Retina Displays

Font Awesome icons are vectors, which mean they're gorgeous on high-resolution displays.

#### Made for Bootstrap

Designed from scratch to be fully compatible with Bootstrap 2.3.2.

#### Desktop Friendly

To use on the desktop or for a complete set of vectors, check out the cheatsheet.

#### Screen Reader Compatible

Font Awesome won't trip up screen readers, unlike other icon fonts.

## Thanks To

Thanks to @robmadole and @supercodepoet for icon design review, advice, some Jekyll help, and being all around badass coders.

Thanks to @grantgordon and @johnsmclay for developing and hosting icnfnt, the best way to subset Font Awesome.

Thanks to MaxCDN for providing the excellent BootstrapCDN, the fastest and easiest way to get started with Font Awesome.